#
# spec file for package python3-numpydoc
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-numpydoc
Version:        0.5
Release:        4.2
Summary:        Sphinx extension to support docstrings in Numpy format
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/numpy/numpydoc
Source:         https://pypi.python.org/packages/source/n/numpydoc/numpydoc-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements
BuildRequires:  python3-Sphinx >= 1.0.1
BuildRequires:  python3-nose
Requires:       python3-Sphinx >= 1.0.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Numpy's documentation uses several custom extensions to Sphinx.  These
are shipped in this numpydoc package, in case you want to make use
of them in third-party projects.

%prep
%setup -q -n numpydoc-%{version}
2to3 -wvn .

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%{python3_sitelib}/numpydoc/
%{python3_sitelib}/numpydoc-%{version}-py*.egg-info

%changelog
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * remove 1220 ifdef
  * autosummary_generate doesn't seem to be shipped anymore, removed it.
  * removed update-alternatives (not needed w/o autosummary_generate)
  * README.txt -> README.rst
  * added nose
- update to version 0.5 (taken from git log):
  * DOC link to NumPy/SciPy documentation guide
  * BUG: Use getfullargspec() on Python 3
  * DOC: add travis link to readme
  * listcomp -> for-loop (listcopms create a new scope in py3), bypass
    AttributeError on Pandas.str
  * TST: skip tests on Py3 for modules that have not been ported
  * MAINT: add Travis CI
  * BUG: fix config loading in SphinxDoc*
  * Use .rst extension for README so it gets rendered on Github
  * Document numpydoc_class_members_toctree option
  * Add config option for adding :toctree: on autosummary lists.
  * Point URL to something that actually exists
  * Bump version since 0.4 has been released
  * Handle Unicode docstrings on Python 2.x correctly
  * Add .gitignore
  * MAINT: Remove outdated version checks.
  * ENH: Allow unnamed return values in Returns section of doc string
  * Fix np domain to avoid duplicate module indices in docs
  * BUG: sphinxext: fix sphinx extensions broken recently
  * BUG: Fix typo in docscrape_sphinx.py import.
  * 2to3: Apply unicode fixer.
  * 2to3: Apply next fixer.
  * 2to3: Apply zip fixer.
  * 2to3: Apply `print` fixer.
  * 2to3: Apply `imports` fixer.
  * 2to3: Add `from __future__ import ...` to new files.
  * 2to3: Use absolute imports.
  * DOC: Used regex to find colons missing spaces which render wrong
    online, also other spacing or formatting mistakes
  * 2to3: Put `from __future__ import division in every python file.
  * 2to3: Apply `funcattrs` fixer. Closes #3058.
  * 2to3: apply exec fixer results.
  * 2to3: Fix callable.
  * 2to3: Remove `has_key` use that was missed.
  * 2to3: Updata `except Exception, msg:` syntax in files not in
    numpy/ .
  * BUG: numpydoc: check that it works with sub-classes
  * TST: numpydoc: more class tests
  * BUG: numpydoc: fix bugs in attribute docstring extraction +
    improve presentation
  * TST: numpydoc: add stub test files, to check that files at least
    import
  * ENH: numpydoc: Python 2 & 3 in single codebase, restructure as a
    package
  * ENH: numpydoc: deal with duplicated signatures
  * DOC: numpydoc/linkcode: mention that the extension will be in
    Sphinx upstream
  * BUG: numpydoc/linkcode: do not detect linkcode config changes
  * DOC: Used regex to find colons missing spaces which render wrong
    online, also other spacing or formatting mistakes
  * sphinxext: remove mention of old files in LICENSE.txt
  * sphinxext: some cleanup in setup.py
  * DOC: generate links to source code
  * DOC: numpydoc.py was still using old, scipy trac url in docstring
  * sphinxext: expose __call__ in the documentation, if it is present
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Oct 31 2013 toddrme2178@gmail.com
- Implement update-alternatives
* Thu Aug 15 2013 speilicke@suse.com
- Buildrequire python3-2to3 only on 12.2
- Rename spec / changes file to project name
* Mon Aug 12 2013 speilicke@suse.com
- Initial version
